@@ -95,7 +95,8 @@ class RiakClientOperations(RiakClientTransport):
 
     @retryable
     def get_index(self, transport, bucket, index, startkey, endkey=None,
-                  return_terms=None, max_results=None, continuation=None):
+                  return_terms=None, max_results=None, continuation=None,
+                  timeout=None, term_regex=None):
         """
         get_index(bucket, index, startkey, endkey=None, return_terms=None,\
                   max_results=None, continuation=None)
@@ -120,21 +121,30 @@ class RiakClientOperations(RiakClientTransport):
         :param continuation: the opaque continuation returned from a
             previous paginated request
         :type continuation: string
+        :param timeout: a timeout value in milliseconds, or 'infinity'
+        :type timeout: int
+        :param term_regex: a regular expression used to filter index terms
+        :type term_regex: string
         :rtype: :class:`riak.client.index_page.IndexPage`
         """
+        if timeout != 'infinity':
+            _validate_timeout(timeout)
+
         page = IndexPage(self, bucket, index, startkey, endkey,
-                         return_terms, max_results)
+                         return_terms, max_results, term_regex)
 
         results, continuation = transport.get_index(
             bucket, index, startkey, endkey, return_terms=return_terms,
-            max_results=max_results, continuation=continuation)
+            max_results=max_results, continuation=continuation,
+            timeout=timeout, term_regex=term_regex)
 
         page.results = results
         page.continuation = continuation
         return page
 
     def stream_index(self, bucket, index, startkey, endkey=None,
-                     return_terms=None, max_results=None, continuation=None):
+                     return_terms=None, max_results=None, continuation=None,
+                     timeout=None, term_regex=None):
         """
         Queries a secondary index, streaming matching keys through an
         iterator.
@@ -154,15 +164,23 @@ class RiakClientOperations(RiakClientTransport):
         :param continuation: the opaque continuation returned from a
             previous paginated request
         :type continuation: string
+        :param timeout: a timeout value in milliseconds, or 'infinity'
+        :type timeout: int
+        :param term_regex: a regular expression used to filter index terms
+        :type term_regex: string
         :rtype: :class:`riak.client.index_page.IndexPage`
         """
-        page = IndexPage(self, bucket, index, startkey, endkey,
-                         return_terms, max_results)
+        if timeout != 'infinity':
+            _validate_timeout(timeout)
+
         with self._transport() as transport:
+            page = IndexPage(self, bucket, index, startkey, endkey,
+                             return_terms, max_results, term_regex)
             page.stream = True
             page.results = transport.stream_index(
                 bucket, index, startkey, endkey, return_terms=return_terms,
-                max_results=max_results, continuation=continuation)
+                max_results=max_results, continuation=continuation,
+                timeout=timeout, term_regex=term_regex)
             return page
 
     @retryable
@@ -525,6 +543,7 @@ class RiakClientOperations(RiakClientTransport):
 
     increment_counter = update_counter
 
+
 def _validate_timeout(timeout):
     """
     Raises an exception if the given timeout is an invalid value.
